@@ -1,12 +1,12 @@
 /*
-  This file is Copyright © 1994-1995 Olivier Montanuy,
-               Copyright © 1999-2005 André Majorel,
-               Copyright © 2006-2018 contributors to the DeuTex project.
+  Copyright ® Olivier Montanuy,
+              André Majorel,
+              contributors to the DeuTex project.
 
   DeuTex incorporates code derived from DEU 5.21 that was put in the
   public domain in 1994 by Raphaël Quinet and Brendon Wyber.
 
-  SPDX-License-Identifier: GPL-2.0+
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 /** PNM module **/
